@@ -25,6 +25,7 @@
 
 QHash<QString, QPixmap> Utils::m_imgCacheHash;
 QHash<QString, QString> Utils::m_fontNameCache;
+QString Utils::cpuModeName;
 
 const char kLauncherService[] = "com.deepin.dde.daemon.Launcher";
 const char kLauncherIface[] = "/com/deepin/dde/daemon/Launcher";
@@ -38,7 +39,7 @@ QString languageArr[][langCount] = {
     {"accounts", "帐户设置", "Accounts", "賬號設置", "帳戶設定"},
     {"cloudsync", "Union ID", "Union ID", "Union ID", "Union ID"},
     {"display", "显示设置", "Display", "顯示設置", "螢幕設定"},
-    {"defapp", "默认程序设置", "Default Application", "默認程序設置", "預設程式"},
+    {"defapp", "默认程序设置", "Default Applications", "默認程序設置", "預設程式"},
     {"personalization", "个性化设置", "Personalization Settings", "個性化設置", "個性化設定"},
     {"network", "网络设置", "Network Settings", "網絡設置", "網路設定"},
     {"notification", "通知设置", "Notification Settings", "通知設置", "通知設定"},
@@ -53,7 +54,8 @@ QString languageArr[][langCount] = {
     {"update", "系统更新", "Update Settings", "更新", "檢查更新"},
     {"systeminfo", "系统信息", "System Info", "系統訊息", "系統資訊"},
     {"License activator", "授权管理", "Authorization Management", "授權管理", "授權管理"},
-    {"commoninfo", "通用设置", "General Settings", "通用設置", "一般設定"}};
+    {"commoninfo", "通用设置", "General Settings", "通用設置", "一般設定"},
+    {"touchscreen", "触控屏设置", "Touch Screen", "觸控屏設置", "觸控屏設定"}};
 
 struct ReplyStruct {
     QString m_desktop;
@@ -214,6 +216,26 @@ QList<AppInfo> Utils::launcherInterface()
     }
 }
 
+/**
+ * @brief Utils::judgeWayLand
+ * @return
+ * 判断是否为wayland
+ */
+bool Utils::judgeWayLand()
+{
+   auto env = QProcessEnvironment::systemEnvironment();
+
+   QString XDG_SESSION_TYPE = env.value(QStringLiteral("XDG_SESSION_TYPE"));
+
+   QString WAYLAND_DISPLAY = env.value(QStringLiteral("WAYLAND_DISPLAY"));
+
+   if (XDG_SESSION_TYPE == QLatin1String("wayland") || WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)){
+      return true;
+   }
+
+   return false;
+}
+
 /**
  * @brief Utils::getSystemManualList
  * @return　返回系统中存在帮助手册的应用列表
@@ -225,7 +247,6 @@ QStringList Utils::getSystemManualList()
         {"org.deepin.flatdeb.deepin-music", "deepin-music"},
         {"org.deepin.flatdeb.deepin-screenshot", "deepin-screenshot"},
         {"org.deepin.flatdeb.deepin-voice-recorder", "deepin-voice-recorder"},
-        {"deepin-cloud-print-configurator", "deepin-cloud-print"},
         {"org.deepin.flatdeb.deepin-image-viewer", "deepin-image-viewer"},
         {"deepin-cloud-scan-configurator", "deepin-cloud-scan"},
         {"org.deepin.flatdeb.deepin-movie", "deepin-movie"},
@@ -235,15 +256,30 @@ QStringList Utils::getSystemManualList()
     };
 
     QStringList app_list_;
+    //调用dbus服务获取系统安装应用
     const AppInfoList list = launcherInterface();
     const QStringList applicationList = QDir(QString("%1/application/").arg(DMAN_MANUAL_DIR)).entryList();
     const QStringList systemList = QDir(QString("%1/system/").arg(DMAN_MANUAL_DIR)).entryList();
 
-#if 1 //旧文案结构兼容
     QString oldMdPath = DMAN_MANUAL_DIR;
-    if (Dtk::Core::DSysInfo::DeepinServer == Dtk::Core::DSysInfo::deepinType()) {
+
+#if (DTK_VERSION > DTK_VERSION_CHECK(5, 4, 12, 0))
+    if (Dtk::Core::DSysInfo::UosServer == Dtk::Core::DSysInfo::uosType()) {
         oldMdPath += "/server";
-    } else if (Dtk::Core::DSysInfo::DeepinPersonal == Dtk::Core::DSysInfo::deepinType()) {
+    } else if (Dtk::Core::DSysInfo::UosHome == Dtk::Core::DSysInfo::uosEditionType()) {
+        oldMdPath += "/personal";
+    } else if (Dtk::Core::DSysInfo::UosEducation == Dtk::Core::DSysInfo::uosEditionType()) {
+        oldMdPath += "/education";
+    } else if (Dtk::Core::DSysInfo::UosCommunity == Dtk::Core::DSysInfo::uosEditionType()) {
+        oldMdPath += "/community";
+    } else {
+        oldMdPath += "/professional";
+    }
+#else
+    Dtk::Core::DSysInfo::DeepinType nType = Dtk::Core::DSysInfo::deepinType();
+    if (Dtk::Core::DSysInfo::DeepinServer == nType) {
+        oldMdPath += "/server";
+    } else if (Dtk::Core::DSysInfo::DeepinPersonal == nType) {
         oldMdPath += "/personal";
     } else {
         if (Dtk::Core::DSysInfo::isCommunityEdition()) {
@@ -252,8 +288,9 @@ QStringList Utils::getSystemManualList()
             oldMdPath += "/professional";
         }
     }
-    const QStringList oldAppList = QDir(oldMdPath).entryList();
+
 #endif
+    const QStringList oldAppList = QDir(oldMdPath).entryList();
 
     QMultiMap<qlonglong, AppInfo> appMap;
     for (int var = 0; var < list.size(); ++var) {
@@ -262,6 +299,7 @@ QStringList Utils::getSystemManualList()
     //安装时间相同时,按名称排序
     QList<AppInfo> listApp = sortAppList(appMap);
 
+    //比对存在帮助md文件的应用
     for (int i = 0; i < listApp.size(); ++i) {
         const QString app_name = kAppNameMap.value(listApp.at(i).key, listApp.at(i).key);
         if ((applicationList.contains(app_name) || oldAppList.contains(app_name))  && app_list_.indexOf(app_name) == -1) {
@@ -361,6 +399,7 @@ QList<AppInfo> Utils::sortAppList(QMultiMap<qlonglong, AppInfo> map)
 bool Utils::hasSelperSupport()
 {
     int nType = Dtk::Core::DSysInfo::deepinType();
+    //专业版判断是否有服务与支持
     if (Dtk::Core::DSysInfo::DeepinProfessional == (Dtk::Core::DSysInfo::DeepinType)nType) {
         const QStringList list = getSystemManualList();
         if (list.contains("uos-service-support")) {
@@ -403,26 +442,16 @@ QStringList Utils::systemToOmit(Dtk::Core::DSysInfo::UosEdition type)
         retList.append("eu");
         retList.append("s");
         break;
+    //教育版
+    case Dtk::Core::DSysInfo::UosEducation:
+        retList.append("edu");
+        break;
     default:
         break;
     }
     return retList;
 }
 
-/**
- * @brief Utils::isMostPriority 判断当前文件是否为最优先级文件
- * @param mdPath
- * @param morePriorityPath
- * @return
- */
-bool Utils::isMostPriority(const QString &mdPath, QString &morePriorityPath)
-{
-    Q_UNUSED(mdPath);
-    Q_UNUSED(morePriorityPath);
-
-    return  true;
-}
-
 bool Utils::activeWindow(quintptr winId)
 {
     bool bsuccess = true;
@@ -453,6 +482,53 @@ QString Utils::regexp_label(const QString &strtext, const QString &strpatter)
     return result;
 }
 
+QString Utils::mkMutiDir(const QString &path)
+{
+    QDir dir(path);
+    if (path.isEmpty() || dir.exists()) {
+        return path;
+    }
+    QString parentDir = mkMutiDir(path.mid(0, path.lastIndexOf('/')));
+    QString dirname = path.mid(path.lastIndexOf('/') + 1);
+    QDir parentPath(parentDir);
+    if (!dirname.isEmpty()) {
+        bool ret = parentPath.mkpath(dirname);
+        qDebug() << "mkpath result:" << ret << dirname;
+    }
+    return parentDir + "/" + dirname;
+}
+
+/**
+ * @brief Utils::judgeLongson
+ * @node 判断龙芯
+ * @return
+ */
+bool Utils::judgeLoongson()
+{
+    if (cpuModeName.isEmpty()) {
+        QProcess process;
+        //获取CPU型号
+        process.start("cat /proc/cpuinfo");
+
+        if (process.waitForFinished()) {
+            QString result = process.readAllStandardOutput();
+
+            if (result.contains("Loongson")) {
+                qWarning() << "cpu mode name is loongson";
+                cpuModeName = "Loongson";
+            } else {
+                cpuModeName = "other";
+            }
+        }
+    }
+
+    if (cpuModeName.contains("Loongson")) {
+        return  true;
+    }
+
+    return false;
+}
+
 ExApplicationHelper *ExApplicationHelper::instance()
 {
     return qobject_cast<ExApplicationHelper *>(DGuiApplicationHelper::instance());
@@ -579,15 +655,13 @@ DPalette ExApplicationHelper::palette(const QWidget *widget, const QPalette &bas
 
     DPalette palette;
 
-    do {
-        // 存在自定义palette时应该根据其自定义的palette获取对应色调的DPalette
-        const QPalette &wp = widget->palette();
+    // 存在自定义palette时应该根据其自定义的palette获取对应色调的DPalette
+    const QPalette &wp = widget->palette();
 
-        palette = standardPalette(toColorType(wp));
+    palette = standardPalette(toColorType(wp));
 
-        // 关注控件palette改变的事件
-        const_cast<QWidget *>(widget)->installEventFilter(const_cast<ExApplicationHelper *>(this));
-    } while (false);
+    // 关注控件palette改变的事件
+    const_cast<QWidget *>(widget)->installEventFilter(const_cast<ExApplicationHelper *>(this));
 
     return palette;
 }
