@@ -163,13 +163,16 @@ void SearchDb::initConnections()
  */
 void SearchDb::initDb()
 {
-    QString dbdir = QStandardPaths::writableLocation(QStandardPaths::HomeLocation).append("/.local/share/deepin/deepin-manual");
+    //获取本地配置文件目录
+    QString dbdir = Utils::mkMutiDir(QStandardPaths::writableLocation(QStandardPaths::HomeLocation).append("/.local/share/deepin/deepin-manual"));
+    qDebug() << dbdir;
     QDir dir(dbdir);
     if (!dir.exists()) {
-        dir.mkdir(dbdir);
+        qCritical() << __FUNCTION__ << "db path not exist!" << dbdir;
     }
     QString databasePath = dbdir.append("/search.db");
 
+    //创建数据库
     p_->db = QSqlDatabase::addDatabase("QSQLITE", QUuid::createUuid().toString(QUuid::WithoutBraces));
     p_->db.setDatabaseName(databasePath);
     if (!p_->db.open()) {
@@ -189,6 +192,7 @@ void SearchDb::initSearchTable()
     Q_ASSERT(p_->db.isOpen());
     QSqlQuery query(p_->db);
 
+    //创建相关表
     if (!query.exec(kSearchTableSchema)) {
         qCritical() << "Failed to initialize search table:" << query.lastError().text();
         return;
@@ -229,6 +233,7 @@ void SearchDb::addSearchEntry(const QString &app_name, const QString &lang,
             strManualPath = "/application";
         }
 
+        //图片路径替换为绝对路径
         for (int i = 0; i < contents.size(); i++) {
             QString content = contents.at(i);
             content = content.replace("icon/", DMAN_INSTALL_DB_PATH + strManualPath
@@ -256,7 +261,11 @@ void SearchDb::addSearchEntry(const QString &app_name, const QString &lang,
     }
 
     QSqlQuery query(p_->db);
-    query.prepare(kSearchDeleteEntryByApp);
+    bool preok = query.prepare(kSearchDeleteEntryByApp);
+    if(!preok){
+        qCritical() << "Failed to prepare skSearchDeleteEntryByApp:" << query.lastError().text();
+        return;
+    }
     query.bindValue(0, app_name);
     query.bindValue(1, lang);
     if (!query.exec()) {
@@ -268,7 +277,11 @@ void SearchDb::addSearchEntry(const QString &app_name, const QString &lang,
         qWarning() << "Failed to start db transaction!";
         return;
     }
-    query.prepare(kSearchInsertEntry);
+    preok = query.prepare(kSearchInsertEntry);
+    if(!preok){
+        qCritical() << "Failed to prepare kSearchInsertEntry:" << query.lastError().text();
+        return;
+    }
     QStringList app_names;
     QStringList lang_list;
     for (int i = 0; i < anchors.length(); ++i) {
@@ -307,7 +320,11 @@ void SearchDb::deleteSearchInfo(const QStringList &appName, const QStringList &l
 {
     Q_ASSERT(p_->db.isOpen());
     QSqlQuery query(p_->db);
-    query.prepare(kSearchDeleteEntryByApp);
+    bool preok = query.prepare(kSearchDeleteEntryByApp);
+    if(!preok){
+        qCritical() << "Failed to prepare kSearchDeleteEntryByApp:" << query.lastError().text();
+        return;
+    }
     query.bindValue(0, appName);
     query.bindValue(1, lang);
     if (!query.execBatch()) {
@@ -518,6 +535,7 @@ void SearchDb::sortSearchList(const QString &appName, const QStringList &anchors
     obj.contents = contents;
 
     if (anchorIds.contains("h0")) {
+        //发送查询结果->SearchManager::searchContentResult->SearchProxy::onContentResult->js
         emit this->searchContentResult(obj.appName, obj.anchors, obj.anchorIds, obj.contents);
         nH0OfList++;
         //        listStruct.insert(0, obj);
@@ -592,6 +610,7 @@ void SearchDb::handleSearchContent(const QString &keyword)
 
     //屏蔽部分特殊字符，会导致JS层对HTML无法对应替换
     if (keyword.contains(QRegExp("[|&-]"))) {
+        //发送未查找到结果->SearchManager::searchContentMismatch->SearchProxy::mismatch->JS
         emit this->searchContentMismatch(keyword);
         return;
     }
@@ -688,6 +707,7 @@ void SearchDb::handleSearchContent(const QString &keyword)
         for (searchStrct obj : listStruct) {
             if (result_empty)
                 result_empty = false;
+            //发送查询结果->SearchManager::searchContentResult->SearchProxy::onContentResult->js
             emit this->searchContentResult(obj.appName, obj.anchors, obj.anchorIds, obj.contents);
         }
     } else {
@@ -696,6 +716,7 @@ void SearchDb::handleSearchContent(const QString &keyword)
 
     if (result_empty && 0 == nH0OfList) {
         qDebug() << "searchContentMismatch";
+        //发送未查找到结果->SearchManager::searchContentMismatch->SearchProxy::mismatch->JS
         emit this->searchContentMismatch(keyword);
     }
 }
@@ -713,7 +734,11 @@ void SearchDb::insertFilesTimeEntry(const QStringList &listMdPath, const QString
     Q_ASSERT(p_->db.isOpen());
 
     QSqlQuery query(p_->db);
-    query.prepare(kfileTimeDeleteEntryByApp);
+    bool preok = query.prepare(kfileTimeDeleteEntryByApp);
+    if(!preok){
+        qCritical() << "Failed to prepare kSearchDeleteEntryByApp:" << query.lastError().text();
+        return;
+    }
     query.bindValue(0, listMdPath);
     if (!query.execBatch()) {
         qCritical() << "Failed to delete fileTime entry:" << query.lastError().text();
@@ -724,7 +749,11 @@ void SearchDb::insertFilesTimeEntry(const QStringList &listMdPath, const QString
         qWarning() << "Failed to start db transaction!";
         return;
     }
-    query.prepare(kfileTimeInsertEntry);
+    preok = query.prepare(kfileTimeInsertEntry);
+    if(!preok){
+        qCritical() << "Failed to prepare kfileTimeInsertEntry:" << query.lastError().text();
+        return;
+    }
     query.bindValue(0, listMdPath);
     query.bindValue(1, listDataTime);
     bool ok = query.execBatch();
@@ -733,8 +762,8 @@ void SearchDb::insertFilesTimeEntry(const QStringList &listMdPath, const QString
         p_->db.rollback();
         qCritical() << "Failed to insert fileTime " << query.lastError().text();
     } else {
-        p_->db.commit();
-        qCritical() << "insert fileTime";
+        bool ret = p_->db.commit();
+        qCritical() << "insert fileTime" << ret;
     }
 }
 
@@ -747,7 +776,11 @@ void SearchDb::deleteFilesTimeEntry(const QStringList &listMdPath)
     Q_ASSERT(p_->db.isOpen());
 
     QSqlQuery query(p_->db);
-    query.prepare(kfileTimeDeleteEntryByApp);
+    bool preok = query.prepare(kfileTimeDeleteEntryByApp);
+    if(!preok){
+        qCritical() << "Failed to prepare kfileTimeDeleteEntryByApp:" << query.lastError().text();
+        return;
+    }
     query.bindValue(0, listMdPath);
     bool ok = query.execBatch();
     if (!ok) {
