@@ -40,12 +40,12 @@
 #include <QWebChannel>
 #include <QWindow>
 #include <QX11Info>
-
 #include <QRegion>
 #include <QFocusEvent>
 #include <QWebEngineHistory>
 #include <QTime>
-#include "base/utils.h"
+#include <QClipboard>
+#include <QNetworkProxyFactory>
 
 namespace {
 
@@ -64,15 +64,20 @@ WebWindow::WebWindow(QWidget *parent)
     search_timer_.setSingleShot(true);
     setAttribute(Qt::WA_InputMethodEnabled, true);
 
+    //初始化窗口
     this->initUI();
+    //初始化信号
     this->initConnections();
+    //初始化快捷键
     this->initShortcuts();
+    //初始化dbus服务
     this->initDBus();
     qApp->installEventFilter(this);
 }
 
 WebWindow::~WebWindow()
 {
+    //释放各个资源
     if (completion_window_ != nullptr) {
         delete completion_window_;
         completion_window_ = nullptr;
@@ -142,10 +147,13 @@ void WebWindow::updatePage(const QStringList &list)
             appList.append(splitList.at(splitList.count() - 4));
         }
 
+        //发送到前端页面更新内容
         emit search_proxy_->reloadPage(appList);
     }
 
     if (search_manager_) {
+        //重新获取应用列表
+        //SearchDb::updateModule-->SearchDb::getAllApp
         emit search_manager_->updateModule();
     }
 }
@@ -157,6 +165,9 @@ void WebWindow::updateBtnBox()
 {
     if (m_forwardButton->isEnabled() || m_backButton->isEnabled()) {
         buttonBox->show();
+        //wayland下， 窗口焦点在qwebengines上时，如果titlebar原有没有buttonbox，将titlebar上buttonbox->show（）后会出现黑方角，像是没有渲染完成一样。。。。
+        //避免方法：刷新一次主窗口。。
+        this->update();
     } else {
         buttonBox->hide();
     }
@@ -174,6 +185,7 @@ void WebWindow::cancelTextChanged()
 
 /**
  * @brief WebWindow::openjsPage
+ * @note 根据应用名和标题名定位到当前页面
  * @param app_name
  * @param title_name
  */
@@ -218,28 +230,48 @@ void WebWindow::slot_ThemeChanged()
 {
     DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
     QColor fillColor = DGuiApplicationHelper::instance()->applicationPalette().highlight().color();
-    if (themeType == DGuiApplicationHelper::DarkType) {
-        web_view_->page()->setBackgroundColor(QColor(37, 37, 37));
-    } else {
-        web_view_->page()->setBackgroundColor(QColor(248, 248, 248));
+    if(!Utils::judgeWayLand()){
+
+        if (themeType == DGuiApplicationHelper::DarkType) {
+            web_view_->page()->setBackgroundColor(QColor(37, 37, 37));
+        } else {
+            web_view_->page()->setBackgroundColor(QColor(248, 248, 248));
+        }
+    }else {
+        if (themeType == DGuiApplicationHelper::DarkType) {
+            web_view_->page()->setBackgroundColor(QColor(0x28, 0x28, 0x28));
+            QPalette pa = palette();
+            pa.setColor(QPalette::Window, QColor("#161616"));
+            setPalette(pa);
+        } else if (themeType == DGuiApplicationHelper::LightType) {
+            QPalette pa = palette();
+            pa.setColor(QPalette::Window, Qt::white);
+            setPalette(pa);
+            web_view_->page()->setBackgroundColor(QColor(248, 248, 248));
+        }
     }
     web_view_->page()->runJavaScript(QString("setHashWordColor('%1')").arg(fillColor.name()));
 }
 
 /**
- * @brief WebWindow::slot_HelpSupportTriggered  服务与支持触发槽
+ * @brief WebWindow::HelpSupportTriggered  服务与支持响应处理
+ * @param bActiontrigger   是否为菜单触发
  */
-void WebWindow::slot_HelpSupportTriggered()
+void WebWindow::HelpSupportTriggered(bool bActiontrigger)
 {
     QDBusInterface interface("com.deepin.dde.ServiceAndSupport",
-                                 "/com/deepin/dde/ServiceAndSupport",
-                                 "com.deepin.dde.ServiceAndSupport");
+                             "/com/deepin/dde/ServiceAndSupport",
+                             "com.deepin.dde.ServiceAndSupport");
 
     //    selfSupport = 0, //自助支持
     //    messageConsultation = 1, //留言咨询
     //    customerChat = 2, //在线客服
     //    contentUs = 3 //联系我们
-    QDBusReply<void> reply = interface.call("ServiceSession", 0);
+    uint8_t supporttype = 0;
+    if (!bActiontrigger) {
+        supporttype = 2;
+    }
+    QDBusReply<void> reply = interface.call("ServiceSession", supporttype);
     if (reply.isValid()) {
         qDebug() << "call com.deepin.dde.ServiceAndSupport success";
     } else {
@@ -264,6 +296,32 @@ void WebWindow::closeEvent(QCloseEvent *event)
     QWidget::closeEvent(event);
 }
 
+/**
+ * @brief WebWindow::resizeEvent
+ * @param event
+ * 拖拽调整窗口大小时重新设置搜索结果位置
+ */
+void WebWindow::resizeEvent(QResizeEvent *event)
+{
+    Q_UNUSED(event);
+    if(completion_window_->isVisible()){
+        completion_window_->autoResize();
+        // Move to below of search edit.
+        const QPoint local_point(this->rect().width() / 2 - search_edit_->width() / 2,
+                                 titlebar()->height() - 3);
+        if(!Utils::judgeWayLand()){
+            const QPoint global_point(this->mapToGlobal(local_point));
+            completion_window_->move(global_point);
+        }else {
+            completion_window_->move(local_point);
+        }
+    }
+
+    if(web_view_){
+        slot_ThemeChanged();
+    }
+}
+
 /**
  * @brief WebWindow::inputMethodEvent
  * @param e
@@ -289,19 +347,13 @@ QVariant WebWindow::inputMethodQuery(Qt::InputMethodQuery prop) const
     switch (prop) {
     case Qt::ImEnabled:
         return true;
-    case Qt::ImCursorRectangle:
     default:
-        ;
+        break;
     }
 
     return QWidget::inputMethodQuery(prop);
 }
 
-void WebWindow::resizeEvent(QResizeEvent *event)
-{
-    QWidget::resizeEvent(event);
-}
-
 
 /**
  * @brief WebWindow::eventFilter
@@ -312,15 +364,14 @@ void WebWindow::resizeEvent(QResizeEvent *event)
  */
 bool WebWindow::eventFilter(QObject *watched, QEvent *event)
 {
-    if (event->type() == QEvent::MouseButtonRelease && qApp->activeWindow() == this &&
-            watched->objectName() == QLatin1String("QMainWindowClassWindow")) {
+    //warland环境下watched的objectname不是QMainWindowClassWindow,先去除验证
+    if (event->type() == QEvent::MouseButtonRelease && qApp->activeWindow() == this ) {
         QRect rect = hasWidgetRect(search_edit_);
         if (web_view_ && web_view_->selectedText().isEmpty() && !rect.contains(QCursor::pos())) {
             this->setFocus();
         }
     }
-    if (event->type() == QEvent::KeyPress && qApp->activeWindow() == this &&
-            watched->objectName() == QLatin1String("QMainWindowClassWindow")) {
+    if (event->type() == QEvent::KeyPress && qApp->activeWindow() == this ) {
         QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
         if (keyEvent->key() == Qt::Key_V
                 && keyEvent->modifiers().testFlag(Qt::ControlModifier)) {
@@ -336,7 +387,7 @@ bool WebWindow::eventFilter(QObject *watched, QEvent *event)
                     || (keyEvent->key() <= Qt::Key_9 && keyEvent->key() >= Qt::Key_0)
                     || (keyEvent->key() == Qt::Key_Space))
                    && keyEvent->modifiers() == Qt::NoModifier) {
-            search_edit_->lineEdit()->setFocus();
+                search_edit_->lineEdit()->setFocus();
         } else if (keyEvent->key() == Qt::Key_Enter || keyEvent->key() == Qt::Key_Return) {
             if (search_edit_->lineEdit()->hasFocus()) {
                 //搜索框内容为空时，按回车键回到未搜索页面
@@ -347,16 +398,19 @@ bool WebWindow::eventFilter(QObject *watched, QEvent *event)
             }
         } else if (keyEvent->key() == Qt::Key_A
                    && keyEvent->modifiers().testFlag(Qt::ControlModifier)) {
-            web_view_->setFocus(Qt::ActiveWindowFocusReason);
+            //搜索框全选
+            if (!search_edit_->lineEdit()->hasFocus()) {
+                web_view_->setFocus(Qt::ActiveWindowFocusReason);
+            }
         }
     }
 
     // Filters mouse press event only.
-    if (event->type() == QEvent::MouseButtonPress && qApp->activeWindow() == this &&
-            watched->objectName() == QLatin1String("QMainWindowClassWindow")) {
+    if (event->type() == QEvent::MouseButtonPress && qApp->activeWindow() == this) {
+
         QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
-        //        this->web_view_->update();
-        if (mouseEvent->button()) {
+
+        if(nullptr != mouseEvent){
             switch (mouseEvent->button()) {
             case Qt::BackButton: {
                 qDebug() << "eventFilter back";
@@ -368,12 +422,15 @@ bool WebWindow::eventFilter(QObject *watched, QEvent *event)
                 emit title_bar_proxy_->forwardButtonClicked();
                 break;
             }
-            case Qt::MiddleButton: {
+            case Qt::MiddleButton:
                 return true;
+            default:
+                break;
             }
-            default: {
-            }
-            }
+        }
+
+        //wayland 当搜索结果隐藏之后,将无法触发鼠标点击事件无法跳转内容
+        if(!Utils::judgeWayLand()){
             if (!hasWidgetRect(search_edit_).contains(mapFromGlobal(QCursor::pos()))) {
                 completion_window_->hide();
             }
@@ -401,8 +458,10 @@ void WebWindow::setSearchManager()
 {
     search_proxy_ = new SearchProxy(this);
     search_manager_ = new SearchManager(this);
+    //searchContentResult绑定到JS页面
     connect(search_manager_, &SearchManager::searchContentResult, search_proxy_,
             &SearchProxy::onContentResult);
+    //searchContentMismatch绑定到JS页面
     connect(search_manager_, &SearchManager::searchContentMismatch, search_proxy_,
             &SearchProxy::mismatch);
     connect(search_manager_, &SearchManager::searchAnchorResult, this,
@@ -449,6 +508,11 @@ void WebWindow::onManualSearchByKeyword(const QString &keyword)
  */
 void WebWindow::onAppearanceChanged(QString, QMap<QString, QVariant> map, QStringList)
 {
+    //20210630codereview
+    if (map.isEmpty()) {
+        return;
+    }
+
     QString strValue = map.begin().value().toString();
     QString strKey = map.begin().key();
     qDebug() << __func__ << " key: " << strKey << " value: " << strValue;
@@ -474,8 +538,14 @@ void WebWindow::onAppearanceChanged(QString, QMap<QString, QVariant> map, QStrin
 void WebWindow::initUI()
 {
     //搜索结果框可移至主窗口创建完成后
-    completion_window_ = new SearchCompletionWindow();
+    if(!Utils::judgeWayLand()){
+        completion_window_ = new SearchCompletionWindow();
+    }else {
+        completion_window_ = new SearchCompletionWindow(this);
+        completion_window_->hide();
+    }
 
+    setFocus(Qt::ActiveWindowFocusReason);
     // 初始化标题栏
     QHBoxLayout *buttonLayout = new QHBoxLayout;
     buttonLayout->setMargin(0);
@@ -518,18 +588,21 @@ void WebWindow::initUI()
         QAction *pHelpSupport = new QAction(QObject::tr("Support"));
         pMenu->addAction(pHelpSupport);
         this->titlebar()->setMenu(pMenu);
-        connect(pHelpSupport, &QAction::triggered, this, &WebWindow::slot_HelpSupportTriggered);
+        connect(pHelpSupport, &QAction::triggered, this, [this] { this->HelpSupportTriggered(true); });
     }
     this->titlebar()->addWidget(buttonFrame, Qt::AlignLeft);
     this->titlebar()->addWidget(search_edit_, Qt::AlignCenter);
     this->titlebar()->setSeparatorVisible(false);
     this->titlebar()->setIcon(QIcon::fromTheme("deepin-manual"));
-    //通过强制设置主题获取图标后，dtk获取图标失败，此处临时方案，后续进行源码级修复
-    QIcon::fromTheme("mark_indicator");
+
+    if(Utils::judgeWayLand()){
+        this->titlebar()->setAutoFillBackground(false);
+        this->titlebar()->setBackgroundRole(QPalette::Window);
+    }
     //隐藏title阴影
     this->setTitlebarShadowEnabled(false);
     //键盘盲打
-    search_edit_->setFocus();
+    // search_edit_->setFocus();
     this->setFocusPolicy(Qt::ClickFocus);
 
     QWidget *spinnerPage = new QWidget;
@@ -547,25 +620,44 @@ void WebWindow::initUI()
  */
 void WebWindow::initWebView()
 {
+    //图片控件
     image_viewer_ = new ImageViewer(this);
+    //图片显示
     image_viewer_proxy_ = new ImageViewerProxy(image_viewer_, this);
+    //主题代理类
     theme_proxy_ = new ThemeProxy(this);
+    //设置代理类
     settings_proxy_ = new SettingsProxy(this);
+    //语言代理类
     i18n_proxy = new I18nProxy(this);
+    //手册处理代理类
     manual_proxy_ = new ManualProxy(this);
-
+    //标题栏代理类
     title_bar_proxy_ = new TitleBarProxy(this);
+
+    //上一页按钮
     connect(m_backButton, &DButtonBoxButton::clicked, title_bar_proxy_,
             &TitleBarProxy::backwardButtonClicked);
+    //下一页按钮
     connect(m_forwardButton, &DButtonBoxButton::clicked, title_bar_proxy_,
             &TitleBarProxy::forwardButtonClicked);
     web_view_ = new QWebEngineView;
-    web_view_->setAttribute(Qt::WA_NativeWindow, true);
+    web_view_->setAttribute(Qt::WA_KeyCompression, true);
+    web_view_->setAttribute(Qt::WA_InputMethodEnabled, true);
+
+    if(!Utils::judgeWayLand()){
+        web_view_->setAttribute(Qt::WA_NativeWindow, true);
+    }
+    QNetworkProxyFactory::setUseSystemConfiguration(false);
+
+    //禁止拖文件
     web_view_->setAcceptDrops(false);
     //使用该方法效果最好但使用后消息提示控件不可见,所以根据主题设置相适应的背景色
     // web_view_->page()->setBackgroundColor(Qt::transparent);
+    //根据系统主题设置web背景色
     slot_ThemeChanged();
     QWebChannel *web_channel = new QWebChannel;
+    //向web页面注册C++类对象
     web_channel->registerObject("i18n", i18n_proxy);
     web_channel->registerObject("imageViewer", image_viewer_proxy_);
     web_channel->registerObject("manual", manual_proxy_);
@@ -579,17 +671,21 @@ void WebWindow::initWebView()
     connect(manual_proxy_, &ManualProxy::channelInit, this, &WebWindow::onChannelFinish);
     connect(manual_proxy_, &ManualProxy::WidgetLower, this, &WebWindow::lower);
     connect(manual_proxy_, &ManualProxy::updateLabel, this, &WebWindow::slotUpdateLabel);
-    connect(manual_proxy_, &ManualProxy::supportBeClick, this, &WebWindow::slot_HelpSupportTriggered);
+    connect(manual_proxy_, &ManualProxy::supportBeClick, this, [this] { this->HelpSupportTriggered(); });
 
+    //web主页html路径
     const QFileInfo info(kIndexPage);
     web_view_->load(QUrl::fromLocalFile(info.absoluteFilePath()));
     connect(search_edit_, &SearchEdit::onClickedClearBtn, manual_proxy_,
             &ManualProxy::searchEditTextisEmpty);
     connect(search_proxy_, &SearchProxy::setKeyword, this, &WebWindow::onSetKeyword);
     connect(search_proxy_, &SearchProxy::updateSearchResult, this, &WebWindow::onTitleBarEntered);
+
+    //接收系统主题变化信号发送给前端JS
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged,
             theme_proxy_, &ThemeProxy::slot_ThemeChange);
 
+    //接收系统主题变化信号
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged,
             this, &WebWindow::slot_ThemeChanged);
 
@@ -620,25 +716,13 @@ void WebWindow::initShortcuts()
     scWndReize->setContext(Qt::WindowShortcut);
     scWndReize->setAutoRepeat(false);
     connect(scWndReize, &QShortcut::activated, this, [this] {
-        if (this->windowState() & Qt::WindowMaximized)
-        {
+        if (this->windowState() & Qt::WindowMaximized){
             this->showNormal();
-        } else if (this->windowState() == Qt::WindowNoState)
-        {
+        } else if (this->windowState() == Qt::WindowNoState){
             this->showMaximized();
         }
     });
 
-//    //设置全选切换快捷键
-//    QShortcut *sCheckAll = new QShortcut(this);
-//    sCheckAll->setKey(tr("Ctrl+A"));
-//    sCheckAll->setContext(Qt::WindowShortcut);
-//    sCheckAll->setAutoRepeat(false);
-//    connect(sCheckAll, &QShortcut::activated, this, [this] {
-
-//        web_view_->setFocus();
-//    });
-
     //设置搜索快捷键  后期将支持盲打功能,故不需要此快捷键
     QShortcut *scSearch = new QShortcut(this);
     scSearch->setKey(tr("Ctrl+F"));
@@ -656,12 +740,12 @@ void WebWindow::initDBus()
 {
     QDBusConnection senderConn = QDBusConnection::connectToBus(QDBusConnection::SessionBus, "Sender");
     if (!senderConn.connect(
-            "com.deepin.daemon.Appearance", // sender's service name
-            "/com/deepin/daemon/Appearance", // sender's path name
-            "org.freedesktop.DBus.Properties", // interface
-            "PropertiesChanged", // sender's signal name
-            this, // receiver
-            SLOT(onAppearanceChanged(QString, QMap<QString, QVariant>, QStringList)))) {
+                "com.deepin.daemon.Appearance", // sender's service name
+                "/com/deepin/daemon/Appearance", // sender's path name
+                "org.freedesktop.DBus.Properties", // interface
+                "PropertiesChanged", // sender's signal name
+                this, // receiver
+                SLOT(onAppearanceChanged(QString, QMap<QString, QVariant>, QStringList)))) {
         qDebug() << "connectToBus()::connect()  PropertiesChanged failed";
     } else {
         qDebug() << "connectToBus()::connect()  PropertiesChanged success";
@@ -691,6 +775,7 @@ void WebWindow::settingContextMenu()
         web_view_->setContextMenuPolicy(Qt::CustomContextMenu);
     });
     QMenu *menu = new QMenu(this);
+    //文案内容右键显示复制
     QAction *action = menu->addAction(QObject::tr("Copy"));
     connect(web_view_, &QWidget::customContextMenuRequested, this, [ = ]() {
         if (!web_view_->selectedText().isEmpty()) {
@@ -731,6 +816,7 @@ void WebWindow::onSearchContentByKeyword(const QString &keyword)
     qDebug() << "calling keyword is:" << keyword << endl;
     QString key(keyword);
     const QString searchKey = key.remove('\n').remove('\r').remove("\r\n").remove(QRegExp("\\s"));
+    //在数据库中查询->SearchDb::searchContent->SearchDb::handleSearchContent
     search_manager_->searchContent(searchKey);
 
     QString base64Key = QString(searchKey.toUtf8().toBase64());
@@ -759,6 +845,7 @@ void WebWindow::onSearchButtonClicked()
 {
     QString textTemp = search_edit_->text();
     const QString text = textTemp.remove('\n').remove('\r').remove("\r\n");
+    //根据关键字在内容中查找
     this->onSearchContentByKeyword(text);
     completion_window_->hide();
 }
@@ -822,9 +909,6 @@ void WebWindow::onTitleBarEntered()
     if (text.size() >= 1) {
         completion_window_->onEnterPressed();
     }
-    //    else if (textTemp.isEmpty()) {
-    //        m_backButton->click();
-    //    }
 }
 
 /**
@@ -902,12 +986,14 @@ void WebWindow::onSetKeyword(const QString &keyword)
 
     if (search_edit_) {
         if (keyword.isEmpty()) {
+            //清空搜索框
             search_edit_->clearEdit();
         } else {
             QString strTemp = keyword;
             if (strTemp.contains("=-=")) {
                 strTemp.replace("=-=", "%");
             }
+            //设置搜索框值
             search_edit_->setText(strTemp);
         }
     }
@@ -925,7 +1011,6 @@ void WebWindow::onSearchAnchorResult(const QString &keyword, const SearchAnchorR
         return;
     }
 
-    Q_UNUSED(keyword);
     if (result.isEmpty()) {
         // Hide completion window if no anchor entry matches.
         completion_window_->hide();
@@ -937,8 +1022,13 @@ void WebWindow::onSearchAnchorResult(const QString &keyword, const SearchAnchorR
         // Move to below of search edit.
         const QPoint local_point(this->rect().width() / 2 - search_edit_->width() / 2,
                                  titlebar()->height() - 3);
-        const QPoint global_point(this->mapToGlobal(local_point));
-        completion_window_->move(global_point);
+        if(!Utils::judgeWayLand()){
+            const QPoint global_point(this->mapToGlobal(local_point));
+            completion_window_->move(global_point);
+        }else {
+            completion_window_->move(local_point);
+        }
+
         completion_window_->setFocusPolicy(Qt::NoFocus);
         completion_window_->setFocusPolicy(Qt::StrongFocus);
     }
