@@ -22,10 +22,15 @@
 #include "gtest/gtest.h"
 #include <QTest>
 
+class ConfigManager;
+
 class ut_config_manager_test : public ::testing::Test
 {
 public:
     ut_config_manager_test();
+
+protected:
+    ConfigManager *m_ap = nullptr;
 };
 
 #endif // UT_CONFIG_MANAGER_TEST_H
