@@ -22,13 +22,12 @@
 #include "gtest/gtest.h"
 #include <QTest>
 
-namespace dman {
 
 class ut_search_manager_test : public ::testing::Test
 {
 public:
     ut_search_manager_test();
+    QString stub_writableLocation();
 };
 
-} // namespace dman
 #endif // UT_SEARCH_MANAGER_TEST_H
