@@ -18,8 +18,9 @@
 #ifndef UT_SHELLOBJ_H
 #define UT_SHELLOBJ_H
 
-#include <QObject>
 #include "gtest/gtest.h"
+
+#include <QObject>
 #include <QtTest>
 
 class shellObj;
@@ -30,7 +31,7 @@ public:
     virtual void SetUp() override;
     virtual void TearDown() override;
 protected:
-    shellObj *m_so;
+    shellObj *m_so = nullptr;
 };
 
 #endif // UT_SHELLOBJ_H
