@@ -24,32 +24,52 @@ ut_ManualOpenAdapter::ut_ManualOpenAdapter()
 
 void ut_ManualOpenAdapter::SetUp()
 {
-    widget = new QWidget;
-    adapter = new ManualOpenAdapter(widget);
+    adapter = new ManualOpenAdapter(this);
 }
 
 void ut_ManualOpenAdapter::TearDown()
 {
     delete adapter;
-    delete widget;
+}
+
+void ut_ManualOpenAdapter::Open(const QString &app_name)
+{
+    isopen = true;
+}
+
+void ut_ManualOpenAdapter::OpenTitle(const QString &app_name, const QString &title_name)
+{
+    isOpenTitle = true;
+}
+void ut_ManualOpenAdapter::ShowManual(const QString &app_name)
+{
+    isShowManual = true;
+}
+void ut_ManualOpenAdapter::Search(const QString &keyword)
+{
+    isSearch = true;
 }
 
 TEST_F(ut_ManualOpenAdapter, open)
 {
     adapter->Open("dde");
+    ASSERT_TRUE(isopen);
 }
 
 TEST_F(ut_ManualOpenAdapter, OpenTitle)
 {
     adapter->OpenTitle("deepin-a", "a");
+    ASSERT_TRUE(isOpenTitle);
 }
 
 TEST_F(ut_ManualOpenAdapter, Search)
 {
     adapter->Search("a");
+    ASSERT_TRUE(isSearch);
 }
 
 TEST_F(ut_ManualOpenAdapter, ShowManual)
 {
     adapter->ShowManual("deepin");
+    ASSERT_TRUE(isShowManual);
 }
