@@ -18,7 +18,9 @@
 #ifndef UT_TITLEBARPROXY_H
 #define UT_TITLEBARPROXY_H
 
+#include "view/web_window.h"
 #include "gtest/gtest.h"
+
 #include <QTest>
 
 class TitleBarProxy;
@@ -31,6 +33,7 @@ public:
     virtual void SetUp() override;
     virtual void TearDown() override;
     TitleBarProxy *m_tbp = nullptr;
+     WebWindow web;
 
 };
 
