@@ -18,24 +18,37 @@
 #ifndef UT_WEB_WINDOW_TEST_H
 #define UT_WEB_WINDOW_TEST_H
 
-#include <QMainWindow>
 #include "gtest/gtest.h"
-#include <QTest>
+
 #include <DObject>
 #include <DApplicationHelper>
 
+#include <QTest>
+#include <QMainWindow>
+#include <QWebChannel>
+#include <QWebEnginePage>
+
 DWIDGET_USE_NAMESPACE
 
 class WebWindow;
-namespace dman {
 
 class ut_web_window_test : public ::testing::Test
 {
 public:
     explicit ut_web_window_test();
-    virtual void SetUp() override;
-    virtual void TearDown() override;
-    WebWindow *window;
+
+    void stub_initweb();
+    bool stub_isValid();
+    bool stub_isValidfalse();
+    void stub_setWeb(QWebChannel*);
+    QWebEnginePage* stub_page();
+    WebWindow *window = nullptr;
+    DGuiApplicationHelper::ColorType stub_themeType() const;
+    DGuiApplicationHelper::ColorType stub_themeTypeDark() const;
+    QString stub_selectText() const;
+    Qt::MouseButton stub_MouseButtonBack() const;
+    Qt::MouseButton stub_MouseButtonForward() const;
+    Qt::MouseButton stub_MouseButtonMiddle() const;
 };
-} // namespace dman
+
 #endif // UT_WEB_WINDOW_TEST_H
